@@ -6,7 +6,7 @@ package Dist::Zilla::PluginBundle::Author::KENTNL;
 
 # ABSTRACT: BeLike::KENTNL when you build your distributions.
 
-our $VERSION = '2.025010';
+our $VERSION = '2.025020';
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
@@ -45,7 +45,16 @@ use namespace::autoclean;
 
 
 
-sub mvp_multivalue_args { return qw( auto_prereqs_skip copyfiles ) }
+
+sub mvp_multivalue_args { return qw( auto_prereqs_skip copy_files ) }
+
+sub mvp_aliases {
+  return {
+    'bumpversions' => 'bump_versions',
+    'srcreadme'    => 'src_readme',
+    'copyfiles'    => 'copy_files',
+  };
+}
 
 
 
@@ -253,7 +262,7 @@ has 'toolkit' => (
 
 
 
-has 'bumpversions' => (
+has 'bump_versions' => (
   is      => ro  =>,
   isa     => 'Bool',
   lazy    => 1,
@@ -275,7 +284,7 @@ has 'bumpversions' => (
 
 
 
-has copyfiles => (
+has copy_files => (
   is   => ro =>,
   isa  => 'ArrayRef[ Str ]',
   lazy => 1,
@@ -290,7 +299,7 @@ has copyfiles => (
 
 
 
-has srcreadme => (
+has src_readme => (
   is => ro =>,
   isa => enum( [ 'pod', 'mkdn', 'none' ] ),
   lazy    => 1,
@@ -349,9 +358,9 @@ sub add_named_plugin {
 
 sub _is_bake { return ( current_cmd() and 'bakeini' eq current_cmd() ) }
 
-sub _configure_bumpversions_version {
+sub _configure_bump_versions_version {
   my ( $self, ) = @_;
-  return if $self->bumpversions;
+  return if $self->bump_versions;
   $self->add_plugin(
     'Git::NextVersion::Sanitized' => {
       version_regexp => '^(.*)-source$',
@@ -405,11 +414,12 @@ sub _none_match {
 sub _configure_basic_files {
   my ($self)         = @_;
   my (@ignore_files) = qw( README README.mkdn README.pod CONTRIBUTING.pod );
-  my (@copyfiles)    = ();
-  if ( _none_match 'none', @{ $self->copyfiles } ) {
-    push @copyfiles, @{ $self->copyfiles };
+  my (@copy_files)   = ();
+
+  if ( _none_match 'none', @{ $self->copy_files } ) {
+    push @copy_files, @{ $self->copy_files };
   }
-  push @ignore_files, @copyfiles;
+  push @ignore_files, @copy_files;
 
   $self->add_plugin(
     'Git::GatherDir' => {
@@ -432,8 +442,8 @@ sub _configure_basic_files {
     },
   );
 
-  if (@copyfiles) {
-    $self->add_named_plugin( 'CopyXBuild' => 'CopyFilesFromBuild', { copy => [@copyfiles] } );
+  if (@copy_files) {
+    $self->add_named_plugin( 'CopyXBuild' => 'CopyFilesFromBuild', { copy => [@copy_files] } );
   }
 
   return;
@@ -455,7 +465,7 @@ sub _configure_basic_tests {
 
 sub _configure_pkgversion_munger {
   my ($self) = @_;
-  if ( not $self->bumpversions ) {
+  if ( not $self->bump_versions ) {
     $self->add_plugin( 'PkgVersion' => {} );
     return;
   }
@@ -573,7 +583,7 @@ sub _configure_readmes {
 
   $self->add_named_plugin( 'ShippedReadme' => 'Readme::Brief' => {}, );
 
-  my $type = $self->srcreadme;
+  my $type = $self->src_readme;
 
   return if 'none' eq $type;
 
@@ -595,7 +605,7 @@ sub configure {
   my ($self) = @_;
 
   # Version
-  $self->_configure_bumpversions_version;
+  $self->_configure_bump_versions_version;
 
   # MetaData
   $self->_configure_basic_metadata;
@@ -660,7 +670,7 @@ sub configure {
     },
   );
 
-  if ( $self->bumpversions ) {
+  if ( $self->bump_versions ) {
     $self->add_plugin( 'BumpVersionAfterRelease' => {} );
   }
   $self->add_named_plugin(
@@ -737,7 +747,7 @@ Dist::Zilla::PluginBundle::Author::KENTNL - BeLike::KENTNL when you build your d
 
 =head1 VERSION
 
-version 2.025010
+version 2.025020
 
 =head1 SYNOPSIS
 
@@ -949,31 +959,31 @@ Determines which tooling to generate the distribution with
 
 =back
 
-=head2 C<bumpversions>
+=head2 C<bump_versions>
 
-  bumpversions = 1
+  bump_versions = 1
 
 If true, use C<[BumpVersionAfterRelease]>  and C<[RewriteVersions::Sanitized]> instead of C<[PkgVersion]> and
 C<[Git::NextVersion::Sanitized]>
 
-=head2 C<copyfiles>
+=head2 C<copy_files>
 
 An array of files generated by C<Dist::Zilla> build to copy from the built dist back to the source dist
 
 If not specified, the default contents are as follows:
 
-  copyfiles = LICENSE
-  copyfiles = Makefile.PL
+  copy_files = LICENSE
+  copy_files = Makefile.PL
 
 These defaults can be wiped with:
 
-  copyfiles = none
+  copy_files = none
 
-=head2 C<srcreadme>
+=head2 C<src_readme>
 
-  srcreadme = pod  ; # generate README.pod on the source side
-  srcreadme = mkdn ; # generate README.mkdn on the source side
-  srcreadme = none ; # don't generate README on the source side
+  src_readme = pod  ; # generate README.pod on the source side
+  src_readme = mkdn ; # generate README.mkdn on the source side
+  src_readme = none ; # don't generate README on the source side
 
 =begin MetaPOD::JSON v1.1.0
 
@@ -988,6 +998,7 @@ These defaults can be wiped with:
 =end MetaPOD::JSON
 
 =for Pod::Coverage   mvp_multivalue_args
+  mvp_aliases
   bundle_config_inner
 
 =head1 AUTHOR
@@ -996,7 +1007,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2016 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
