@@ -3,7 +3,9 @@
 sub {
   my ($yaml) = @_;
   splice @{ $yaml->{before_install} }, 1, 0, ('git --version');
-  @{ $yaml->{branches}->{only} } = map { ( $_ eq 'build/master' ) ? 'builds' : $_ } @{ $yaml->{branches}->{only} };
+  splice @{ $yaml->{before_install} }, 1, 0, ('perlbrew install-cpanm -f');
+  unshift @{ $yaml->{install} },
+    ( 'cpanm --verbose --mirror http://cpan.metacpan.org --no-man-pages \'ExtUtils::MakeMaker~>=6.64\' \'LMDB_File~<0.08\'' );
 
   #  @{ $yaml->{matrix}->{include} } = grep { $_->{perl} ne '5.8' }  @{ $yaml->{matrix}->{include} };
 };
